@@ -1,18 +1,19 @@
 import json
 
 from moto.core.responses import BaseResponse
-from .models import athena_backends
+from .models import athena_backends, AthenaBackend
+from typing import Dict, Tuple, Union
 
 
 class AthenaResponse(BaseResponse):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="athena")
 
     @property
-    def athena_backend(self):
+    def athena_backend(self) -> AthenaBackend:
         return athena_backends[self.current_account][self.region]
 
-    def create_work_group(self):
+    def create_work_group(self) -> Union[Tuple[str, Dict[str, int]], str]:
         name = self._get_param("Name")
         description = self._get_param("Description")
         configuration = self._get_param("Configuration")
@@ -32,14 +33,14 @@ class AthenaResponse(BaseResponse):
             }
         )
 
-    def list_work_groups(self):
+    def list_work_groups(self) -> str:
         return json.dumps({"WorkGroups": self.athena_backend.list_work_groups()})
 
-    def get_work_group(self):
+    def get_work_group(self) -> str:
         name = self._get_param("WorkGroup")
         return json.dumps({"WorkGroup": self.athena_backend.get_work_group(name)})
 
-    def start_query_execution(self):
+    def start_query_execution(self) -> Union[Tuple[str, Dict[str, int]], str]:
         query = self._get_param("QueryString")
         context = self._get_param("QueryExecutionContext")
         config = self._get_param("ResultConfiguration")
@@ -51,7 +52,7 @@ class AthenaResponse(BaseResponse):
         )
         return json.dumps({"QueryExecutionId": q_exec_id})
 
-    def get_query_execution(self):
+    def get_query_execution(self) -> str:
         exec_id = self._get_param("QueryExecutionId")
         execution = self.athena_backend.get_execution(exec_id)
         result = {
@@ -78,18 +79,18 @@ class AthenaResponse(BaseResponse):
         }
         return json.dumps(result)
 
-    def stop_query_execution(self):
+    def stop_query_execution(self) -> str:
         exec_id = self._get_param("QueryExecutionId")
         self.athena_backend.stop_query_execution(exec_id)
         return json.dumps({})
 
-    def error(self, msg, status):
+    def error(self, msg: str, status: int) -> Tuple[str, Dict[str, int]]:
         return (
             json.dumps({"__type": "InvalidRequestException", "Message": msg}),
             dict(status=status),
         )
 
-    def create_named_query(self):
+    def create_named_query(self) -> Union[Tuple[str, Dict[str, int]], str]:
         name = self._get_param("Name")
         description = self._get_param("Description")
         database = self._get_param("Database")
@@ -102,32 +103,32 @@ class AthenaResponse(BaseResponse):
         )
         return json.dumps({"NamedQueryId": query_id})
 
-    def get_named_query(self):
+    def get_named_query(self) -> str:
         query_id = self._get_param("NamedQueryId")
         nq = self.athena_backend.get_named_query(query_id)
         return json.dumps(
             {
                 "NamedQuery": {
-                    "Name": nq.name,
-                    "Description": nq.description,
-                    "Database": nq.database,
-                    "QueryString": nq.query_string,
-                    "NamedQueryId": nq.id,
-                    "WorkGroup": nq.workgroup,
+                    "Name": nq.name,  # type: ignore[union-attr]
+                    "Description": nq.description,  # type: ignore[union-attr]
+                    "Database": nq.database,  # type: ignore[union-attr]
+                    "QueryString": nq.query_string,  # type: ignore[union-attr]
+                    "NamedQueryId": nq.id,  # type: ignore[union-attr]
+                    "WorkGroup": nq.workgroup,  # type: ignore[union-attr]
                 }
             }
         )
 
-    def list_data_catalogs(self):
+    def list_data_catalogs(self) -> str:
         return json.dumps(
             {"DataCatalogsSummary": self.athena_backend.list_data_catalogs()}
         )
 
-    def get_data_catalog(self):
+    def get_data_catalog(self) -> str:
         name = self._get_param("Name")
         return json.dumps({"DataCatalog": self.athena_backend.get_data_catalog(name)})
 
-    def create_data_catalog(self):
+    def create_data_catalog(self) -> Union[Tuple[str, Dict[str, int]], str]:
         name = self._get_param("Name")
         catalog_type = self._get_param("Type")
         description = self._get_param("Description")
