@@ -1,18 +1,13 @@
-from functools import lru_cache
-
 import datetime
 import inspect
 import re
 from botocore.exceptions import ClientError
-from boto3 import Session
-from moto.settings import allow_unknown_region
-from threading import RLock
-from typing import Any, Optional, List
+from typing import Any, Optional, List, Callable, Dict
 from urllib.parse import urlparse
-from uuid import uuid4
+from .common_types import TYPE_RESPONSE
 
 
-def camelcase_to_underscores(argument: Optional[str]) -> str:
+def camelcase_to_underscores(argument: str) -> str:
     """Converts a camelcase param like theNewAttribute to the equivalent
     python underscore variable like the_new_attribute"""
     result = ""
@@ -38,7 +33,7 @@ def camelcase_to_underscores(argument: Optional[str]) -> str:
     return result
 
 
-def underscores_to_camelcase(argument):
+def underscores_to_camelcase(argument: str) -> str:
     """Converts a camelcase param like the_new_attribute to the equivalent
     camelcase version like theNewAttribute. Note that the first letter is
     NOT capitalized by this function"""
@@ -54,31 +49,31 @@ def underscores_to_camelcase(argument):
     return result
 
 
-def pascal_to_camelcase(argument):
+def pascal_to_camelcase(argument: str) -> str:
     """Converts a PascalCase param to the camelCase equivalent"""
     return argument[0].lower() + argument[1:]
 
 
-def camelcase_to_pascal(argument):
+def camelcase_to_pascal(argument: str) -> str:
     """Converts a camelCase param to the PascalCase equivalent"""
     return argument[0].upper() + argument[1:]
 
 
-def method_names_from_class(clazz):
+def method_names_from_class(clazz: object) -> List[str]:
     predicate = inspect.isfunction
     return [x[0] for x in inspect.getmembers(clazz, predicate=predicate)]
 
 
-def convert_regex_to_flask_path(url_path):
+def convert_regex_to_flask_path(url_path: str) -> str:
     """
     Converts a regex matching url to one that can be used with flask
     """
     for token in ["$"]:
         url_path = url_path.replace(token, "")
 
-    def caller(reg):
+    def caller(reg: Any) -> str:
         match_name, match_pattern = reg.groups()
-        return '<regex("{0}"):{1}>'.format(match_pattern, match_name)
+        return f'<regex("{match_pattern}"):{match_name}>'
 
     url_path = re.sub(r"\(\?P<(.*?)>(.*?)\)", caller, url_path)
 
@@ -89,20 +84,20 @@ def convert_regex_to_flask_path(url_path):
 
 
 class convert_to_flask_response(object):
-    def __init__(self, callback):
+    def __init__(self, callback: Callable[..., Any]):
         self.callback = callback
 
     @property
-    def __name__(self):
+    def __name__(self) -> str:
         # For instance methods, use class and method names. Otherwise
         # use module and method name
         if inspect.ismethod(self.callback):
             outer = self.callback.__self__.__class__.__name__
         else:
             outer = self.callback.__module__
-        return "{0}.{1}".format(outer, self.callback.__name__)
+        return f"{outer}.{self.callback.__name__}"
 
-    def __call__(self, args=None, **kwargs):
+    def __call__(self, args: Any = None, **kwargs: Any) -> Any:
         from flask import request, Response
         from moto.moto_api import recorder
 
@@ -124,20 +119,20 @@ class convert_to_flask_response(object):
 
 
 class convert_flask_to_responses_response(object):
-    def __init__(self, callback):
+    def __init__(self, callback: Callable[..., Any]):
         self.callback = callback
 
     @property
-    def __name__(self):
+    def __name__(self) -> str:
         # For instance methods, use class and method names. Otherwise
         # use module and method name
         if inspect.ismethod(self.callback):
             outer = self.callback.__self__.__class__.__name__
         else:
             outer = self.callback.__module__
-        return "{0}.{1}".format(outer, self.callback.__name__)
+        return f"{outer}.{self.callback.__name__}"
 
-    def __call__(self, request, *args, **kwargs):
+    def __call__(self, request: Any, *args: Any, **kwargs: Any) -> TYPE_RESPONSE:
         for key, val in request.headers.items():
             if isinstance(val, bytes):
                 request.headers[key] = val.decode("utf-8")
@@ -147,42 +142,44 @@ class convert_flask_to_responses_response(object):
         return status, headers, response
 
 
-def iso_8601_datetime_with_milliseconds(value: datetime) -> str:
+def iso_8601_datetime_with_milliseconds(value: datetime.datetime) -> str:
     return value.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z"
 
 
 # Even Python does not support nanoseconds, other languages like Go do (needed for Terraform)
-def iso_8601_datetime_with_nanoseconds(value):
+def iso_8601_datetime_with_nanoseconds(value: datetime.datetime) -> str:
     return value.strftime("%Y-%m-%dT%H:%M:%S.%f000Z")
 
 
-def iso_8601_datetime_without_milliseconds(value):
-    return None if value is None else value.strftime("%Y-%m-%dT%H:%M:%SZ")
+def iso_8601_datetime_without_milliseconds(value: datetime.datetime) -> Optional[str]:
+    return value.strftime("%Y-%m-%dT%H:%M:%SZ") if value else None
 
 
-def iso_8601_datetime_without_milliseconds_s3(value):
-    return None if value is None else value.strftime("%Y-%m-%dT%H:%M:%S.000Z")
+def iso_8601_datetime_without_milliseconds_s3(
+    value: datetime.datetime,
+) -> Optional[str]:
+    return value.strftime("%Y-%m-%dT%H:%M:%S.000Z") if value else None
 
 
 RFC1123 = "%a, %d %b %Y %H:%M:%S GMT"
 
 
-def rfc_1123_datetime(src):
+def rfc_1123_datetime(src: datetime.datetime) -> str:
     return src.strftime(RFC1123)
 
 
-def str_to_rfc_1123_datetime(value):
+def str_to_rfc_1123_datetime(value: str) -> datetime.datetime:
     return datetime.datetime.strptime(value, RFC1123)
 
 
-def unix_time(dt: datetime.datetime = None) -> datetime.datetime:
+def unix_time(dt: Optional[datetime.datetime] = None) -> float:
     dt = dt or datetime.datetime.utcnow()
     epoch = datetime.datetime.utcfromtimestamp(0)
     delta = dt - epoch
     return (delta.days * 86400) + (delta.seconds + (delta.microseconds / 1e6))
 
 
-def unix_time_millis(dt=None):
+def unix_time_millis(dt: Optional[datetime.datetime] = None) -> float:
     return unix_time(dt) * 1000.0
 
 
@@ -197,28 +194,27 @@ def path_url(url: str) -> str:
 
 
 def tags_from_query_string(
-    querystring_dict, prefix="Tag", key_suffix="Key", value_suffix="Value"
-):
+    querystring_dict: Dict[str, Any],
+    prefix: str = "Tag",
+    key_suffix: str = "Key",
+    value_suffix: str = "Value",
+) -> Dict[str, str]:
     response_values = {}
     for key in querystring_dict.keys():
         if key.startswith(prefix) and key.endswith(key_suffix):
             tag_index = key.replace(prefix + ".", "").replace("." + key_suffix, "")
-            tag_key = querystring_dict.get(
-                "{prefix}.{index}.{key_suffix}".format(
-                    prefix=prefix, index=tag_index, key_suffix=key_suffix
-                )
-            )[0]
-            tag_value_key = "{prefix}.{index}.{value_suffix}".format(
-                prefix=prefix, index=tag_index, value_suffix=value_suffix
-            )
+            tag_key = querystring_dict[f"{prefix}.{tag_index}.{key_suffix}"][0]
+            tag_value_key = f"{prefix}.{tag_index}.{value_suffix}"
             if tag_value_key in querystring_dict:
-                response_values[tag_key] = querystring_dict.get(tag_value_key)[0]
+                response_values[tag_key] = querystring_dict[tag_value_key][0]
             else:
                 response_values[tag_key] = None
     return response_values
 
 
-def tags_from_cloudformation_tags_list(tags_list):
+def tags_from_cloudformation_tags_list(
+    tags_list: List[Dict[str, str]]
+) -> Dict[str, str]:
     """Return tags in dict form from cloudformation resource tags form (list of dicts)"""
     tags = {}
     for entry in tags_list:
@@ -229,7 +225,7 @@ def tags_from_cloudformation_tags_list(tags_list):
     return tags
 
 
-def remap_nested_keys(root, key_transform):
+def remap_nested_keys(root: Any, key_transform: Callable[[str], str]) -> Any:
     """This remap ("recursive map") function is used to traverse and
     transform the dictionary keys of arbitrarily nested structures.
     List comprehensions do not recurse, making it tedious to apply
@@ -256,7 +252,9 @@ def remap_nested_keys(root, key_transform):
     return root
 
 
-def merge_dicts(dict1, dict2, remove_nulls=False):
+def merge_dicts(
+    dict1: Dict[str, Any], dict2: Dict[str, Any], remove_nulls: bool = False
+) -> None:
     """Given two arbitrarily nested dictionaries, merge the second dict into the first.
 
     :param dict dict1: the dictionary to be updated.
@@ -279,7 +277,7 @@ def merge_dicts(dict1, dict2, remove_nulls=False):
                 dict1.pop(key)
 
 
-def aws_api_matches(pattern, string):
+def aws_api_matches(pattern: str, string: str) -> bool:
     """
     AWS API can match a value based on a glob, or an exact match
     """
@@ -300,124 +298,9 @@ def aws_api_matches(pattern, string):
         return False
 
 
-def extract_region_from_aws_authorization(string):
+def extract_region_from_aws_authorization(string: str) -> Optional[str]:
     auth = string or ""
     region = re.sub(r".*Credential=[^/]+/[^/]+/([^/]+)/.*", r"\1", auth)
     if region == auth:
         return None
     return region
-
-
-backend_lock = RLock()
-
-
-class AccountSpecificBackend(dict):
-    """
-    Dictionary storing the data for a service in a specific account.
-    Data access pattern:
-      account_specific_backend[region: str] = backend: BaseBackend
-    """
-
-    def __init__(
-        self, service_name, account_id, backend, use_boto3_regions, additional_regions
-    ):
-        self.service_name = service_name
-        self.account_id = account_id
-        self.backend = backend
-        self.regions = []
-        if use_boto3_regions:
-            sess = Session()
-            self.regions.extend(sess.get_available_regions(service_name))
-            self.regions.extend(
-                sess.get_available_regions(service_name, partition_name="aws-us-gov")
-            )
-            self.regions.extend(
-                sess.get_available_regions(service_name, partition_name="aws-cn")
-            )
-        self.regions.extend(additional_regions or [])
-        self._id = str(uuid4())
-
-    def __hash__(self):
-        return hash(self._id)
-
-    def __eq__(self, other):
-        return (
-            other
-            and isinstance(other, AccountSpecificBackend)
-            and other._id == self._id
-        )
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    def reset(self):
-        for region_specific_backend in self.values():
-            region_specific_backend.reset()
-
-    def __contains__(self, region):
-        return region in self.regions or region in self.keys()
-
-    @lru_cache()
-    def __getitem__(self, region_name):
-        if region_name in self.keys():
-            return super().__getitem__(region_name)
-        # Create the backend for a specific region
-        with backend_lock:
-            if region_name in self.regions and region_name not in self.keys():
-                super().__setitem__(
-                    region_name, self.backend(region_name, account_id=self.account_id)
-                )
-            if region_name not in self.regions and allow_unknown_region():
-                super().__setitem__(
-                    region_name, self.backend(region_name, account_id=self.account_id)
-                )
-        return super().__getitem__(region_name)
-
-
-class BackendDict(dict):
-    """
-    Data Structure to store everything related to a specific service.
-    Format:
-      [account_id: str]: AccountSpecificBackend
-      [account_id: str][region: str] = BaseBackend
-    """
-
-    def __init__(
-        self,
-        backend: Any,
-        service_name: str,
-        use_boto3_regions: bool = True,
-        additional_regions: Optional[List[str]] = None,
-    ):
-        self.backend = backend
-        self.service_name = service_name
-        self._use_boto3_regions = use_boto3_regions
-        self._additional_regions = additional_regions
-        self._id = str(uuid4())
-
-    def __hash__(self):
-        # Required for the LRUcache to work.
-        # service_name is enough to determine uniqueness - other properties are dependent
-        return hash(self._id)
-
-    def __eq__(self, other):
-        return other and isinstance(other, BackendDict) and other._id == self._id
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
-    @lru_cache()
-    def __getitem__(self, account_id) -> AccountSpecificBackend:
-        self._create_account_specific_backend(account_id)
-        return super().__getitem__(account_id)
-
-    def _create_account_specific_backend(self, account_id) -> None:
-        with backend_lock:
-            if account_id not in self.keys():
-                self[account_id] = AccountSpecificBackend(
-                    service_name=self.service_name,
-                    account_id=account_id,
-                    backend=self.backend,
-                    use_boto3_regions=self._use_boto3_regions,
-                    additional_regions=self._additional_regions,
-                )
