@@ -1,9 +1,9 @@
 import collections.abc as collections_abc
-from moto.core.utils import get_random_hex
+from moto.moto_api._internal import mock_random
 
 
 def get_random_pipeline_id():
-    return "df-{0}".format(get_random_hex(length=19))
+    return f"df-{mock_random.get_random_hex(length=19)}"
 
 
 def remove_capitalization_of_dict_keys(obj):
