@@ -45,7 +45,7 @@ class MissingParameterError(EC2ClientError):
     def __init__(self, parameter):
         super().__init__(
             "MissingParameter",
-            "The request must contain the parameter {0}".format(parameter),
+            f"The request must contain the parameter {parameter}",
         )
 
 
@@ -53,7 +53,7 @@ class InvalidDHCPOptionsIdError(EC2ClientError):
     def __init__(self, dhcp_options_id):
         super().__init__(
             "InvalidDhcpOptionID.NotFound",
-            "DhcpOptionID {0} does not exist.".format(dhcp_options_id),
+            f"DhcpOptionID {dhcp_options_id} does not exist.",
         )
 
 
@@ -71,21 +71,21 @@ class MalformedDHCPOptionsIdError(EC2ClientError):
     def __init__(self, dhcp_options_id):
         super().__init__(
             "InvalidDhcpOptionsId.Malformed",
-            'Invalid id: "{0}" (expecting "dopt-...")'.format(dhcp_options_id),
+            f'Invalid id: "{dhcp_options_id}" (expecting "dopt-...")',
         )
 
 
 class InvalidKeyPairNameError(EC2ClientError):
     def __init__(self, key):
         super().__init__(
-            "InvalidKeyPair.NotFound", "The keypair '{0}' does not exist.".format(key)
+            "InvalidKeyPair.NotFound", f"The keypair '{key}' does not exist."
         )
 
 
 class InvalidKeyPairDuplicateError(EC2ClientError):
     def __init__(self, key):
         super().__init__(
-            "InvalidKeyPair.Duplicate", "The keypair '{0}' already exists.".format(key)
+            "InvalidKeyPair.Duplicate", f"The keypair '{key}' already exists."
         )
 
 
@@ -99,16 +99,13 @@ class InvalidKeyPairFormatError(EC2ClientError):
 class InvalidVPCIdError(EC2ClientError):
     def __init__(self, vpc_id):
 
-        super().__init__(
-            "InvalidVpcID.NotFound", "VpcID {0} does not exist.".format(vpc_id)
-        )
+        super().__init__("InvalidVpcID.NotFound", f"VpcID {vpc_id} does not exist.")
 
 
 class InvalidSubnetIdError(EC2ClientError):
     def __init__(self, subnet_id):
         super().__init__(
-            "InvalidSubnetID.NotFound",
-            "The subnet ID '{}' does not exist".format(subnet_id),
+            "InvalidSubnetID.NotFound", f"The subnet ID '{subnet_id}' does not exist"
         )
 
 
@@ -116,9 +113,7 @@ class InvalidFlowLogIdError(EC2ClientError):
     def __init__(self, count, flow_log_ids):
         super().__init__(
             "InvalidFlowLogId.NotFound",
-            "These flow log ids in the input list are not found: [TotalCount: {0}] {1}".format(
-                count, flow_log_ids
-            ),
+            f"These flow log ids in the input list are not found: [TotalCount: {count}] {flow_log_ids}",
         )
 
 
@@ -134,7 +129,7 @@ class InvalidNetworkAclIdError(EC2ClientError):
     def __init__(self, network_acl_id):
         super().__init__(
             "InvalidNetworkAclID.NotFound",
-            "The network acl ID '{0}' does not exist".format(network_acl_id),
+            f"The network acl ID '{network_acl_id}' does not exist",
         )
 
 
@@ -142,7 +137,7 @@ class InvalidVpnGatewayIdError(EC2ClientError):
     def __init__(self, vpn_gw):
         super().__init__(
             "InvalidVpnGatewayID.NotFound",
-            "The virtual private gateway ID '{0}' does not exist".format(vpn_gw),
+            f"The virtual private gateway ID '{vpn_gw}' does not exist",
         )
 
 
@@ -150,9 +145,7 @@ class InvalidVpnGatewayAttachmentError(EC2ClientError):
     def __init__(self, vpn_gw, vpc_id):
         super().__init__(
             "InvalidVpnGatewayAttachment.NotFound",
-            "The attachment with vpn gateway ID '{}' and vpc ID '{}' does not exist".format(
-                vpn_gw, vpc_id
-            ),
+            f"The attachment with vpn gateway ID '{vpn_gw}' and vpc ID '{vpc_id}' does not exist",
         )
 
 
@@ -160,7 +153,7 @@ class InvalidVpnConnectionIdError(EC2ClientError):
     def __init__(self, network_acl_id):
         super().__init__(
             "InvalidVpnConnectionID.NotFound",
-            "The vpnConnection ID '{0}' does not exist".format(network_acl_id),
+            f"The vpnConnection ID '{network_acl_id}' does not exist",
         )
 
 
@@ -168,7 +161,7 @@ class InvalidCustomerGatewayIdError(EC2ClientError):
     def __init__(self, customer_gateway_id):
         super().__init__(
             "InvalidCustomerGatewayID.NotFound",
-            "The customer gateway ID '{0}' does not exist".format(customer_gateway_id),
+            f"The customer gateway ID '{customer_gateway_id}' does not exist",
         )
 
 
@@ -176,7 +169,7 @@ class InvalidNetworkInterfaceIdError(EC2ClientError):
     def __init__(self, eni_id):
         super().__init__(
             "InvalidNetworkInterfaceID.NotFound",
-            "The network interface ID '{0}' does not exist".format(eni_id),
+            f"The network interface ID '{eni_id}' does not exist",
         )
 
 
@@ -184,17 +177,14 @@ class InvalidNetworkAttachmentIdError(EC2ClientError):
     def __init__(self, attachment_id):
         super().__init__(
             "InvalidAttachmentID.NotFound",
-            "The network interface attachment ID '{0}' does not exist".format(
-                attachment_id
-            ),
+            f"The network interface attachment ID '{attachment_id}' does not exist",
         )
 
 
 class InvalidSecurityGroupDuplicateError(EC2ClientError):
     def __init__(self, name):
         super().__init__(
-            "InvalidGroup.Duplicate",
-            "The security group '{0}' already exists".format(name),
+            "InvalidGroup.Duplicate", f"The security group '{name}' already exists"
         )
 
 
@@ -202,7 +192,7 @@ class InvalidSecurityGroupNotFoundError(EC2ClientError):
     def __init__(self, name):
         super().__init__(
             "InvalidGroup.NotFound",
-            "The security group '{0}' does not exist".format(name),
+            f"The security group '{name}' does not exist",
         )
 
 
@@ -225,7 +215,7 @@ class InvalidRouteTableIdError(EC2ClientError):
     def __init__(self, route_table_id):
         super().__init__(
             "InvalidRouteTableID.NotFound",
-            "The routeTable ID '{0}' does not exist".format(route_table_id),
+            f"The routeTable ID '{route_table_id}' does not exist",
         )
 
 
@@ -233,17 +223,14 @@ class InvalidRouteError(EC2ClientError):
     def __init__(self, route_table_id, cidr):
         super().__init__(
             "InvalidRoute.NotFound",
-            "no route with destination-cidr-block {0} in route table {1}".format(
-                cidr, route_table_id
-            ),
+            f"no route with destination-cidr-block {cidr} in route table {route_table_id}",
         )
 
 
 class RouteAlreadyExistsError(EC2ClientError):
     def __init__(self, cidr):
         super().__init__(
-            "RouteAlreadyExists",
-            "The route identified by {0} already exists".format(cidr),
+            "RouteAlreadyExists", f"The route identified by {cidr} already exists"
         )
 
 
@@ -274,7 +261,7 @@ class InvalidAMIIdError(EC2ClientError):
     def __init__(self, ami_id):
         super().__init__(
             "InvalidAMIID.NotFound",
-            "The image id '[{0}]' does not exist".format(ami_id),
+            f"The image id '[{ami_id}]' does not exist",
         )
 
 
@@ -282,7 +269,7 @@ class UnvailableAMIIdError(EC2ClientError):
     def __init__(self, ami_id):
         super().__init__(
             "InvalidAMIID.Unavailable",
-            "The image id '[{0}]' is no longer available".format(ami_id),
+            f"The image id '[{ami_id}]' is no longer available",
         )
 
 
@@ -290,17 +277,14 @@ class InvalidAMIAttributeItemValueError(EC2ClientError):
     def __init__(self, attribute, value):
         super().__init__(
             "InvalidAMIAttributeItemValue",
-            'Invalid attribute item value "{0}" for {1} item type.'.format(
-                value, attribute
-            ),
+            f'Invalid attribute item value "{value}" for {attribute} item type.',
         )
 
 
 class MalformedAMIIdError(EC2ClientError):
     def __init__(self, ami_id):
         super().__init__(
-            "InvalidAMIID.Malformed",
-            'Invalid id: "{0}" (expecting "ami-...")'.format(ami_id),
+            "InvalidAMIID.Malformed", f'Invalid id: "{ami_id}" (expecting "ami-...")'
         )
 
 
@@ -321,8 +305,7 @@ class InvalidSnapshotInUse(EC2ClientError):
 class InvalidVolumeIdError(EC2ClientError):
     def __init__(self, volume_id):
         super().__init__(
-            "InvalidVolume.NotFound",
-            "The volume '{0}' does not exist.".format(volume_id),
+            "InvalidVolume.NotFound", f"The volume '{volume_id}' does not exist."
         )
 
 
@@ -330,9 +313,7 @@ class InvalidVolumeAttachmentError(EC2ClientError):
     def __init__(self, volume_id, instance_id):
         super().__init__(
             "InvalidAttachment.NotFound",
-            "Volume {0} can not be detached from {1} because it is not attached".format(
-                volume_id, instance_id
-            ),
+            f"Volume {volume_id} can not be detached from {instance_id} because it is not attached",
         )
 
 
@@ -340,9 +321,7 @@ class InvalidVolumeDetachmentError(EC2ClientError):
     def __init__(self, volume_id, instance_id, device):
         super().__init__(
             "InvalidAttachment.NotFound",
-            "The volume {0} is not attached to instance {1} as device {2}".format(
-                volume_id, instance_id, device
-            ),
+            f"The volume {volume_id} is not attached to instance {instance_id} as device {device}",
         )
 
 
@@ -350,29 +329,27 @@ class VolumeInUseError(EC2ClientError):
     def __init__(self, volume_id, instance_id):
         super().__init__(
             "VolumeInUse",
-            "Volume {0} is currently attached to {1}".format(volume_id, instance_id),
+            f"Volume {volume_id} is currently attached to {instance_id}",
         )
 
 
 class InvalidDomainError(EC2ClientError):
     def __init__(self, domain):
         super().__init__(
-            "InvalidParameterValue", "Invalid value '{0}' for domain.".format(domain)
+            "InvalidParameterValue", f"Invalid value '{domain}' for domain."
         )
 
 
 class InvalidAddressError(EC2ClientError):
     def __init__(self, ip):
-        super().__init__(
-            "InvalidAddress.NotFound", "Address '{0}' not found.".format(ip)
-        )
+        super().__init__("InvalidAddress.NotFound", f"Address '{ip}' not found.")
 
 
 class LogDestinationNotFoundError(EC2ClientError):
     def __init__(self, bucket_name):
         super().__init__(
             "LogDestinationNotFoundException",
-            "LogDestination: '{0}' does not exist.".format(bucket_name),
+            f"LogDestination: '{bucket_name}' does not exist.",
         )
 
 
@@ -380,7 +357,7 @@ class InvalidAllocationIdError(EC2ClientError):
     def __init__(self, allocation_id):
         super().__init__(
             "InvalidAllocationID.NotFound",
-            "Allocation ID '{0}' not found.".format(allocation_id),
+            f"Allocation ID '{allocation_id}' not found.",
         )
 
 
@@ -388,7 +365,7 @@ class InvalidAssociationIdError(EC2ClientError):
     def __init__(self, association_id):
         super().__init__(
             "InvalidAssociationID.NotFound",
-            "Association ID '{0}' not found.".format(association_id),
+            f"Association ID '{association_id}' not found.",
         )
 
 
@@ -396,9 +373,7 @@ class InvalidVpcCidrBlockAssociationIdError(EC2ClientError):
     def __init__(self, association_id):
         super().__init__(
             "InvalidVpcCidrBlockAssociationIdError.NotFound",
-            "The vpc CIDR block association ID '{0}' does not exist".format(
-                association_id
-            ),
+            f"The vpc CIDR block association ID '{association_id}' does not exist",
         )
 
 
@@ -406,9 +381,7 @@ class InvalidVPCPeeringConnectionIdError(EC2ClientError):
     def __init__(self, vpc_peering_connection_id):
         super().__init__(
             "InvalidVpcPeeringConnectionId.NotFound",
-            "VpcPeeringConnectionID {0} does not exist.".format(
-                vpc_peering_connection_id
-            ),
+            f"VpcPeeringConnectionID {vpc_peering_connection_id} does not exist.",
         )
 
 
@@ -416,9 +389,7 @@ class InvalidVPCPeeringConnectionStateTransitionError(EC2ClientError):
     def __init__(self, vpc_peering_connection_id):
         super().__init__(
             "InvalidStateTransition",
-            "VpcPeeringConnectionID {0} is not in the correct state for the request.".format(
-                vpc_peering_connection_id
-            ),
+            f"VpcPeeringConnectionID {vpc_peering_connection_id} is not in the correct state for the request.",
         )
 
 
@@ -444,9 +415,7 @@ class InvalidDependantParameterError(EC2ClientError):
     def __init__(self, dependant_parameter, parameter, parameter_value):
         super().__init__(
             "InvalidParameter",
-            "{0} can't be empty if {1} is {2}.".format(
-                dependant_parameter, parameter, parameter_value
-            ),
+            f"{dependant_parameter} can't be empty if {parameter} is {parameter_value}.",
         )
 
 
@@ -454,22 +423,20 @@ class InvalidDependantParameterTypeError(EC2ClientError):
     def __init__(self, dependant_parameter, parameter_value, parameter):
         super().__init__(
             "InvalidParameter",
-            "{0} type must be {1} if {2} is provided.".format(
-                dependant_parameter, parameter_value, parameter
-            ),
+            f"{dependant_parameter} type must be {parameter_value} if {parameter} is provided.",
         )
 
 
 class InvalidAggregationIntervalParameterError(EC2ClientError):
     def __init__(self, parameter):
-        super().__init__("InvalidParameter", "Invalid {0}".format(parameter))
+        super().__init__("InvalidParameter", f"Invalid {parameter}")
 
 
 class InvalidParameterValueError(EC2ClientError):
     def __init__(self, parameter_value):
         super().__init__(
             "InvalidParameterValue",
-            "Value {0} is invalid for parameter.".format(parameter_value),
+            f"Value {parameter_value} is invalid for parameter.",
         )
 
 
@@ -492,17 +459,14 @@ class InvalidParameterValueErrorUnknownAttribute(EC2ClientError):
     def __init__(self, parameter_value):
         super().__init__(
             "InvalidParameterValue",
-            "Value ({0}) for parameter attribute is invalid. Unknown attribute.".format(
-                parameter_value
-            ),
+            f"Value ({parameter_value}) for parameter attribute is invalid. Unknown attribute.",
         )
 
 
 class InvalidGatewayIDError(EC2ClientError):
     def __init__(self, gateway_id):
         super().__init__(
-            "InvalidGatewayID.NotFound",
-            "The eigw ID '{0}' does not exist".format(gateway_id),
+            "InvalidGatewayID.NotFound", f"The eigw ID '{gateway_id}' does not exist"
         )
 
 
@@ -510,7 +474,7 @@ class InvalidInternetGatewayIdError(EC2ClientError):
     def __init__(self, internet_gateway_id):
         super().__init__(
             "InvalidInternetGatewayID.NotFound",
-            "InternetGatewayID {0} does not exist.".format(internet_gateway_id),
+            f"InternetGatewayID {internet_gateway_id} does not exist.",
         )
 
 
@@ -518,9 +482,7 @@ class GatewayNotAttachedError(EC2ClientError):
     def __init__(self, internet_gateway_id, vpc_id):
         super().__init__(
             "Gateway.NotAttached",
-            "InternetGatewayID {0} is not attached to a VPC {1}.".format(
-                internet_gateway_id, vpc_id
-            ),
+            f"InternetGatewayID {internet_gateway_id} is not attached to a VPC {vpc_id}.",
         )
 
 
@@ -528,7 +490,7 @@ class ResourceAlreadyAssociatedError(EC2ClientError):
     def __init__(self, resource_id):
         super().__init__(
             "Resource.AlreadyAssociated",
-            "Resource {0} is already associated.".format(resource_id),
+            f"Resource {resource_id} is already associated.",
         )
 
 
@@ -542,14 +504,13 @@ class TagLimitExceeded(EC2ClientError):
 
 class InvalidID(EC2ClientError):
     def __init__(self, resource_id):
-        super().__init__("InvalidID", "The ID '{0}' is not valid".format(resource_id))
+        super().__init__("InvalidID", f"The ID '{resource_id}' is not valid")
 
 
 class InvalidCIDRSubnetError(EC2ClientError):
     def __init__(self, cidr):
         super().__init__(
-            "InvalidParameterValue",
-            "invalid CIDR subnet specification: {0}".format(cidr),
+            "InvalidParameterValue", f"invalid CIDR subnet specification: {cidr}"
         )
 
 
@@ -564,32 +525,29 @@ class RulesPerSecurityGroupLimitExceededError(EC2ClientError):
 class MotoNotImplementedError(NotImplementedError):
     def __init__(self, blurb):
         super().__init__(
-            "{0} has not been implemented in Moto yet."
+            f"{blurb} has not been implemented in Moto yet."
             " Feel free to open an issue at"
-            " https://github.com/spulec/moto/issues".format(blurb)
+            " https://github.com/spulec/moto/issues"
         )
 
 
 class FilterNotImplementedError(MotoNotImplementedError):
     def __init__(self, filter_name, method_name):
-        super().__init__("The filter '{0}' for {1}".format(filter_name, method_name))
+        super().__init__(f"The filter '{filter_name}' for {method_name}")
 
 
 class CidrLimitExceeded(EC2ClientError):
     def __init__(self, vpc_id, max_cidr_limit):
         super().__init__(
             "CidrLimitExceeded",
-            "This network '{0}' has met its maximum number of allowed CIDRs: {1}".format(
-                vpc_id, max_cidr_limit
-            ),
+            f"This network '{vpc_id}' has met its maximum number of allowed CIDRs: {max_cidr_limit}",
         )
 
 
 class UnsupportedTenancy(EC2ClientError):
     def __init__(self, tenancy):
         super().__init__(
-            "UnsupportedTenancy",
-            "The tenancy value {0} is not supported.".format(tenancy),
+            "UnsupportedTenancy", f"The tenancy value {tenancy} is not supported."
         )
 
 
@@ -597,8 +555,7 @@ class OperationNotPermitted(EC2ClientError):
     def __init__(self, association_id):
         super().__init__(
             "OperationNotPermitted",
-            "The vpc CIDR block with association ID {} may not be disassociated. "
-            "It is the primary IPv4 CIDR block of the VPC".format(association_id),
+            f"The vpc CIDR block with association ID {association_id} may not be disassociated. It is the primary IPv4 CIDR block of the VPC",
         )
 
 
@@ -606,10 +563,8 @@ class InvalidAvailabilityZoneError(EC2ClientError):
     def __init__(self, availability_zone_value, valid_availability_zones):
         super().__init__(
             "InvalidParameterValue",
-            "Value ({0}) for parameter availabilityZone is invalid. "
-            "Subnets can currently only be created in the following availability zones: {1}.".format(
-                availability_zone_value, valid_availability_zones
-            ),
+            f"Value ({availability_zone_value}) for parameter availabilityZone is invalid. "
+            f"Subnets can currently only be created in the following availability zones: {valid_availability_zones}.",
         )
 
 
@@ -617,7 +572,7 @@ class AvailabilityZoneNotFromRegionError(EC2ClientError):
     def __init__(self, availability_zone_value):
         super().__init__(
             "InvalidParameterValue",
-            "Invalid Availability Zone ({0})".format(availability_zone_value),
+            f"Invalid Availability Zone ({availability_zone_value})",
         )
 
 
@@ -625,26 +580,20 @@ class NetworkAclEntryAlreadyExistsError(EC2ClientError):
     def __init__(self, rule_number):
         super().__init__(
             "NetworkAclEntryAlreadyExists",
-            "The network acl entry identified by {} already exists.".format(
-                rule_number
-            ),
+            f"The network acl entry identified by {rule_number} already exists.",
         )
 
 
 class InvalidSubnetRangeError(EC2ClientError):
     def __init__(self, cidr_block):
-        super().__init__(
-            "InvalidSubnet.Range", "The CIDR '{}' is invalid.".format(cidr_block)
-        )
+        super().__init__("InvalidSubnet.Range", f"The CIDR '{cidr_block}' is invalid.")
 
 
 class InvalidCIDRBlockParameterError(EC2ClientError):
     def __init__(self, cidr_block):
         super().__init__(
             "InvalidParameterValue",
-            "Value ({}) for parameter cidrBlock is invalid. This is not a valid CIDR block.".format(
-                cidr_block
-            ),
+            f"Value ({cidr_block}) for parameter cidrBlock is invalid. This is not a valid CIDR block.",
         )
 
 
@@ -652,9 +601,7 @@ class InvalidDestinationCIDRBlockParameterError(EC2ClientError):
     def __init__(self, cidr_block):
         super().__init__(
             "InvalidParameterValue",
-            "Value ({}) for parameter destinationCidrBlock is invalid. This is not a valid CIDR block.".format(
-                cidr_block
-            ),
+            f"Value ({cidr_block}) for parameter destinationCidrBlock is invalid. This is not a valid CIDR block.",
         )
 
 
@@ -662,15 +609,13 @@ class InvalidSubnetConflictError(EC2ClientError):
     def __init__(self, cidr_block):
         super().__init__(
             "InvalidSubnet.Conflict",
-            "The CIDR '{}' conflicts with another subnet".format(cidr_block),
+            f"The CIDR '{cidr_block}' conflicts with another subnet",
         )
 
 
 class InvalidVPCRangeError(EC2ClientError):
     def __init__(self, cidr_block):
-        super().__init__(
-            "InvalidVpc.Range", "The CIDR '{}' is invalid.".format(cidr_block)
-        )
+        super().__init__("InvalidVpc.Range", f"The CIDR '{cidr_block}' is invalid.")
 
 
 # accept exception
@@ -678,10 +623,7 @@ class OperationNotPermitted2(EC2ClientError):
     def __init__(self, client_region, pcx_id, acceptor_region):
         super().__init__(
             "OperationNotPermitted",
-            "Incorrect region ({0}) specified for this request."
-            "VPC peering connection {1} must be accepted in region {2}".format(
-                client_region, pcx_id, acceptor_region
-            ),
+            f"Incorrect region ({client_region}) specified for this request.VPC peering connection {pcx_id} must be accepted in region {acceptor_region}",
         )
 
 
@@ -690,10 +632,7 @@ class OperationNotPermitted3(EC2ClientError):
     def __init__(self, client_region, pcx_id, acceptor_region):
         super().__init__(
             "OperationNotPermitted",
-            "Incorrect region ({0}) specified for this request."
-            "VPC peering connection {1} must be accepted or rejected in region {2}".format(
-                client_region, pcx_id, acceptor_region
-            ),
+            f"Incorrect region ({client_region}) specified for this request.VPC peering connection {pcx_id} must be accepted or rejected in region {acceptor_region}",
         )
 
 
@@ -701,8 +640,7 @@ class OperationNotPermitted4(EC2ClientError):
     def __init__(self, instance_id):
         super().__init__(
             "OperationNotPermitted",
-            "The instance '{0}' may not be terminated. Modify its 'disableApiTermination' "
-            "instance attribute and try again.".format(instance_id),
+            f"The instance '{instance_id}' may not be terminated. Modify its 'disableApiTermination' instance attribute and try again.",
         )
 
 
@@ -734,9 +672,7 @@ class InvalidParameterDependency(EC2ClientError):
     def __init__(self, param, param_needed):
         super().__init__(
             "InvalidParameterDependency",
-            "The parameter [{0}] requires the parameter {1} to be set.".format(
-                param, param_needed
-            ),
+            f"The parameter [{param}] requires the parameter {param_needed} to be set.",
         )
 
 
@@ -744,7 +680,7 @@ class IncorrectStateIamProfileAssociationError(EC2ClientError):
     def __init__(self, instance_id):
         super().__init__(
             "IncorrectState",
-            "There is an existing association for instance {0}".format(instance_id),
+            f"There is an existing association for instance {instance_id}",
         )
 
 
@@ -752,7 +688,7 @@ class InvalidAssociationIDIamProfileAssociationError(EC2ClientError):
     def __init__(self, association_id):
         super().__init__(
             "InvalidAssociationID.NotFound",
-            "An invalid association-id of '{0}' was given".format(association_id),
+            f"An invalid association-id of '{association_id}' was given",
         )
 
 
@@ -760,7 +696,7 @@ class InvalidVpcEndPointIdError(EC2ClientError):
     def __init__(self, vpc_end_point_id):
         super().__init__(
             "InvalidVpcEndpointId.NotFound",
-            "The VpcEndPoint ID '{0}' does not exist".format(vpc_end_point_id),
+            f"The VpcEndPoint ID '{vpc_end_point_id}' does not exist",
         )
 
 
@@ -768,9 +704,7 @@ class InvalidTaggableResourceType(EC2ClientError):
     def __init__(self, resource_type):
         super().__init__(
             "InvalidParameterValue",
-            "'{}' is not a valid taggable resource type for this operation.".format(
-                resource_type
-            ),
+            f"'{resource_type}' is not a valid taggable resource type for this operation.",
         )
 
 
@@ -778,7 +712,7 @@ class GenericInvalidParameterValueError(EC2ClientError):
     def __init__(self, attribute, value):
         super().__init__(
             "InvalidParameterValue",
-            "invalid value for parameter {0}: {1}".format(attribute, value),
+            f"invalid value for parameter {attribute}: {value}",
         )
 
 
@@ -786,9 +720,7 @@ class InvalidSubnetCidrBlockAssociationID(EC2ClientError):
     def __init__(self, association_id):
         super().__init__(
             "InvalidSubnetCidrBlockAssociationID.NotFound",
-            "The subnet CIDR block with association ID '{0}' does not exist".format(
-                association_id
-            ),
+            f"The subnet CIDR block with association ID '{association_id}' does not exist",
         )
 
 
@@ -796,7 +728,7 @@ class InvalidCarrierGatewayID(EC2ClientError):
     def __init__(self, carrier_gateway_id):
         super().__init__(
             "InvalidCarrierGatewayID.NotFound",
-            "The CarrierGateway ID '{0}' does not exist".format(carrier_gateway_id),
+            f"The CarrierGateway ID '{carrier_gateway_id}' does not exist",
         )
 
 
