@@ -1,5 +1,4 @@
-from moto.core import BaseBackend
-from moto.core.utils import BackendDict
+from moto.core import BaseBackend, BackendDict
 from ..exceptions import (
     EC2ClientError,
     InvalidID,
