@@ -1,10 +1,9 @@
 import datetime
-
 import pytz
-
 from collections import OrderedDict
-from moto.core import BaseBackend, BaseModel, CloudFormationModel
-from moto.core.utils import BackendDict
+from typing import List, Iterable
+
+from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
 from moto.ec2.models import ec2_backends
 from moto.ec2.exceptions import InvalidInstanceIdError
 from moto.moto_api._internal import mock_random
@@ -44,13 +43,7 @@ class FakeListener(BaseModel):
         self.policy_names = []
 
     def __repr__(self):
-        return "FakeListener(lbp: %s, inp: %s, pro: %s, cid: %s, policies: %s)" % (
-            self.load_balancer_port,
-            self.instance_port,
-            self.protocol,
-            self.ssl_certificate_id,
-            self.policy_names,
-        )
+        return f"FakeListener(lbp: {self.load_balancer_port}, inp: {self.instance_port}, pro: {self.protocol}, cid: {self.ssl_certificate_id}, policies: {self.policy_names})"
 
 
 class FakeBackend(BaseModel):
@@ -59,10 +52,7 @@ class FakeBackend(BaseModel):
         self.policy_names = []
 
     def __repr__(self):
-        return "FakeBackend(inp: %s, policies: %s)" % (
-            self.instance_port,
-            self.policy_names,
-        )
+        return f"FakeBackend(inp: {self.instance_port}, policies: {self.policy_names})"
 
 
 class FakeLoadBalancer(CloudFormationModel):
@@ -92,7 +82,7 @@ class FakeLoadBalancer(CloudFormationModel):
         self.subnets = subnets or []
         self.vpc_id = vpc_id
         self.tags = {}
-        self.dns_name = "%s.us-east-1.elb.amazonaws.com" % (name)
+        self.dns_name = f"{name}.us-east-1.elb.amazonaws.com"
 
         for port in ports:
             listener = FakeListener(
@@ -359,7 +349,7 @@ class ELBBackend(BaseBackend):
 
         return balancer
 
-    def describe_load_balancers(self, names):
+    def describe_load_balancers(self, names: List[str]) -> List[FakeLoadBalancer]:
         balancers = self.load_balancers.values()
         if names:
             matched_balancers = [
@@ -465,8 +455,11 @@ class ELBBackend(BaseBackend):
         return balancer
 
     def register_instances(
-        self, load_balancer_name, instance_ids, from_autoscaling=False
-    ):
+        self,
+        load_balancer_name: str,
+        instance_ids: Iterable[str],
+        from_autoscaling: bool = False,
+    ) -> FakeLoadBalancer:
         load_balancer = self.get_load_balancer(load_balancer_name)
         attr_name = (
             "instance_sparse_ids"
@@ -479,8 +472,11 @@ class ELBBackend(BaseBackend):
         return load_balancer
 
     def deregister_instances(
-        self, load_balancer_name, instance_ids, from_autoscaling=False
-    ):
+        self,
+        load_balancer_name: str,
+        instance_ids: Iterable[str],
+        from_autoscaling: bool = False,
+    ) -> FakeLoadBalancer:
         load_balancer = self.get_load_balancer(load_balancer_name)
         attr_name = (
             "instance_sparse_ids"
@@ -575,12 +571,12 @@ class ELBBackend(BaseBackend):
         return load_balancer
 
     def _register_certificate(self, ssl_certificate_id, dns_name):
-        from moto.acm.models import acm_backends, AWSResourceNotFoundException
+        from moto.acm.models import acm_backends, CertificateNotFound
 
         acm_backend = acm_backends[self.account_id][self.region_name]
         try:
             acm_backend.set_certificate_in_use_by(ssl_certificate_id, dns_name)
-        except AWSResourceNotFoundException:
+        except CertificateNotFound:
             raise CertificateNotFoundException()
 
     def enable_availability_zones_for_load_balancer(
