@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 from urllib.parse import parse_qs
 from botocore.awsrequest import AWSPreparedRequest
 
@@ -32,7 +31,7 @@ def api_version_elb_backend(*args, **kwargs):
     elif "2015-12-01" == version:
         return ELBV2Response.dispatch(*args, **kwargs)
     else:
-        raise Exception("Unknown ELB API version: {}".format(version))
+        raise Exception(f"Unknown ELB API version: {version}")
 
 
 url_bases = [r"https?://elasticloadbalancing\.(.+)\.amazonaws.com"]
