@@ -308,7 +308,7 @@ class ElasticMapReduceResponse(BaseResponse):
                         config.pop(key)
                 config["properties"] = {}
                 map_items = self._get_map_prefix(
-                    "Configurations.member.{0}.Properties.entry".format(idx)
+                    f"Configurations.member.{idx}.Properties.entry"
                 )
                 config["properties"] = map_items
 
@@ -439,7 +439,7 @@ class ElasticMapReduceResponse(BaseResponse):
             iops = "iops"
             volumes_per_instance = "volumes_per_instance"
 
-            key_ebs_optimized = "{0}._{1}".format(key_ebs_config, ebs_optimized)
+            key_ebs_optimized = f"{key_ebs_config}._{ebs_optimized}"
             # EbsOptimized config
             if key_ebs_optimized in ebs_configuration:
                 instance_group.pop(key_ebs_optimized)
@@ -450,12 +450,10 @@ class ElasticMapReduceResponse(BaseResponse):
             # Ebs Blocks
             ebs_blocks = []
             idx = 1
-            keyfmt = "{0}._{1}.member.{{}}".format(
-                key_ebs_config, ebs_block_device_configs
-            )
+            keyfmt = f"{key_ebs_config}._{ebs_block_device_configs}.member.{{}}"
             key = keyfmt.format(idx)
             while self._has_key_prefix(key, ebs_configuration):
-                vlespc_keyfmt = "{0}._{1}._{{}}".format(key, volume_specification)
+                vlespc_keyfmt = f"{key}._{volume_specification}._{{}}"
                 vol_size = vlespc_keyfmt.format(size_in_gb)
                 vol_iops = vlespc_keyfmt.format(iops)
                 vol_type = vlespc_keyfmt.format(volume_type)
@@ -478,7 +476,7 @@ class ElasticMapReduceResponse(BaseResponse):
                         volume_type
                     ] = ebs_configuration.pop(vol_type)
 
-                per_instance = "{0}._{1}".format(key, volumes_per_instance)
+                per_instance = f"{key}._{volumes_per_instance}"
                 if per_instance in ebs_configuration:
                     instance_group.pop(per_instance)
                     ebs_block[volumes_per_instance] = int(
