@@ -8,7 +8,7 @@ class IoTDataPlaneClientError(JsonRESTError):
 class ResourceNotFoundException(IoTDataPlaneClientError):
     def __init__(self):
         self.code = 404
-        super(ResourceNotFoundException, self).__init__(
+        super().__init__(
             "ResourceNotFoundException", "The specified resource does not exist"
         )
 
@@ -16,12 +16,10 @@ class ResourceNotFoundException(IoTDataPlaneClientError):
 class InvalidRequestException(IoTDataPlaneClientError):
     def __init__(self, message):
         self.code = 400
-        super(InvalidRequestException, self).__init__(
-            "InvalidRequestException", message
-        )
+        super().__init__("InvalidRequestException", message)
 
 
 class ConflictException(IoTDataPlaneClientError):
     def __init__(self, message):
         self.code = 409
-        super(ConflictException, self).__init__("ConflictException", message)
+        super().__init__("ConflictException", message)
