@@ -5,11 +5,12 @@ from urllib.parse import unquote
 
 
 class IoTDataPlaneResponse(BaseResponse):
-    SERVICE_NAME = "iot-data"
+    def __init__(self):
+        super().__init__(service_name="iot-data")
 
     @property
     def iotdata_backend(self):
-        return iotdata_backends[self.region]
+        return iotdata_backends[self.current_account][self.region]
 
     def update_thing_shadow(self):
         thing_name = self._get_param("thingName")
