@@ -61,14 +61,12 @@ class KmsResponse(BaseResponse):
         )
 
         if not is_arn and not is_raw_key_id:
-            raise NotFoundException("Invalid keyId {key_id}".format(key_id=key_id))
+            raise NotFoundException(f"Invalid keyId {key_id}")
 
         cmk_id = self.kms_backend.get_key_id(key_id)
 
         if cmk_id not in self.kms_backend.keys:
-            raise NotFoundException(
-                "Key '{key_id}' does not exist".format(key_id=self._display_arn(key_id))
-            )
+            raise NotFoundException(f"Key '{self._display_arn(key_id)}' does not exist")
 
     def _validate_alias(self, key_id):
         """Determine whether an alias exists.
@@ -76,9 +74,7 @@ class KmsResponse(BaseResponse):
         - alias name
         - alias ARN
         """
-        error = NotFoundException(
-            "Alias {key_id} is not found.".format(key_id=self._display_arn(key_id))
-        )
+        error = NotFoundException(f"Alias {self._display_arn(key_id)} is not found.")
 
         is_arn = key_id.startswith("arn:") and ":alias/" in key_id
         is_name = key_id.startswith("alias/")
@@ -211,16 +207,14 @@ class KmsResponse(BaseResponse):
 
         if ":" in alias_name:
             raise ValidationException(
-                "{alias_name} contains invalid characters for an alias".format(
-                    alias_name=alias_name
-                )
+                f"{alias_name} contains invalid characters for an alias"
             )
 
         if not re.match(r"^[a-zA-Z0-9:/_-]+$", alias_name):
             raise ValidationException(
-                "1 validation error detected: Value '{alias_name}' at 'aliasName' "
+                f"1 validation error detected: Value '{alias_name}' at 'aliasName' "
                 "failed to satisfy constraint: Member must satisfy regular "
-                "expression pattern: ^[a-zA-Z0-9:/_-]+$".format(alias_name=alias_name)
+                "expression pattern: ^[a-zA-Z0-9:/_-]+$"
             )
 
         if self.kms_backend.alias_exists(target_key_id):
@@ -232,12 +226,7 @@ class KmsResponse(BaseResponse):
 
         if self.kms_backend.alias_exists(alias_name):
             raise AlreadyExistsException(
-                "An alias with the name arn:aws:kms:{region}:{account_id}:{alias_name} "
-                "already exists".format(
-                    region=self.region,
-                    account_id=self.current_account,
-                    alias_name=alias_name,
-                )
+                f"An alias with the name arn:aws:kms:{self.region}:{self.current_account}:{alias_name} already exists"
             )
 
         self._validate_cmk_id(target_key_id)
