@@ -1,6 +1,5 @@
-from moto.core import BaseBackend
+from moto.core import BaseBackend, BackendDict
 from moto.core.exceptions import RESTError
-from moto.core.utils import BackendDict
 from moto.moto_api._internal import mock_random
 
 from moto.s3 import s3_backends
