@@ -14,14 +14,13 @@ import urllib.parse
 
 from bisect import insort
 from importlib import reload
-from moto.core import BaseBackend, BaseModel, CloudFormationModel
+from moto.core import BaseBackend, BaseModel, BackendDict, CloudFormationModel
 from moto.core import CloudWatchMetricProvider
 from moto.core.utils import (
     iso_8601_datetime_without_milliseconds_s3,
     rfc_1123_datetime,
     unix_time,
     unix_time_millis,
-    BackendDict,
 )
 from moto.cloudwatch.models import MetricDatum
 from moto.moto_api import state_manager
@@ -135,6 +134,7 @@ class FakeKey(BaseModel, ManagedState):
             max_buffer_size if max_buffer_size else get_s3_default_key_buffer_size()
         )
         self._value_buffer = tempfile.SpooledTemporaryFile(self._max_buffer_size)
+        self.disposed = False
         self.value = value
         self.lock = threading.Lock()
 
@@ -304,7 +304,12 @@ class FakeKey(BaseModel, ManagedState):
     # https://docs.python.org/3/library/pickle.html#handling-stateful-objects
     def __getstate__(self):
         state = self.__dict__.copy()
-        state["value"] = self.value
+        try:
+            state["value"] = self.value
+        except ValueError:
+            # Buffer is already closed, so we can't reach the data
+            # Only happens if the key was deleted
+            state["value"] = ""
         del state["_value_buffer"]
         del state["lock"]
         return state
@@ -339,6 +344,22 @@ class FakeKey(BaseModel, ManagedState):
 
         return False
 
+    def dispose(self, garbage=False):
+        if garbage and not self.disposed:
+            import warnings
+
+            warnings.warn("S3 key was not disposed of in time", ResourceWarning)
+        try:
+            self._value_buffer.close()
+            if self.multipart:
+                self.multipart.dispose()
+        except:  # noqa: E722 Do not use bare except
+            pass
+        self.disposed = True
+
+    def __del__(self):
+        self.dispose(garbage=True)
+
 
 class FakeMultipart(BaseModel):
     def __init__(
@@ -401,6 +422,9 @@ class FakeMultipart(BaseModel):
         key = FakeKey(
             part_id, value, encryption=self.sse_encryption, kms_key_id=self.kms_key_id
         )
+        if part_id in self.parts:
+            # We're overwriting the current part - dispose of it first
+            self.parts[part_id].dispose()
         self.parts[part_id] = key
         if part_id not in self.partlist:
             insort(self.partlist, part_id)
@@ -411,6 +435,10 @@ class FakeMultipart(BaseModel):
         for part_id in self.partlist[part_number_marker:max_marker]:
             yield self.parts[part_id]
 
+    def dispose(self):
+        for part in self.parts.values():
+            part.dispose()
+
 
 class FakeGrantee(BaseModel):
     def __init__(self, grantee_id="", uri="", display_name=""):
@@ -867,13 +895,20 @@ class PublicAccessBlock(BaseModel):
         }
 
 
+class MultipartDict(dict):
+    def __delitem__(self, key):
+        if key in self:
+            self[key].dispose()
+        super().__delitem__(key)
+
+
 class FakeBucket(CloudFormationModel):
     def __init__(self, name, account_id, region_name):
         self.name = name
         self.account_id = account_id
         self.region_name = region_name
         self.keys = _VersionedKeyStore()
-        self.multiparts = {}
+        self.multiparts = MultipartDict()
         self.versioning_status = None
         self.rules = []
         self.policy = None
@@ -1421,6 +1456,15 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
             "s3::keyrestore", transition={"progression": "immediate"}
         )
 
+    def reset(self):
+        # For every key and multipart, Moto opens a TemporaryFile to write the value of those keys
+        # Ensure that these TemporaryFile-objects are closed, and leave no filehandles open
+        for mp in FakeMultipart.instances:
+            mp.dispose()
+        for key in FakeKey.instances:
+            key.dispose()
+        super().reset()
+
     @property
     def _url_module(self):
         # The urls-property can be different depending on env variables
@@ -1553,7 +1597,7 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
         else:
             return self.buckets.pop(bucket_name)
 
-    def set_bucket_versioning(self, bucket_name, status):
+    def put_bucket_versioning(self, bucket_name, status):
         self.get_bucket(bucket_name).versioning_status = status
 
     def get_bucket_versioning(self, bucket_name):
@@ -1589,10 +1633,12 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
             # Filter for keys that start with prefix
             if not name.startswith(prefix):
                 continue
-            # separate out all keys that contain delimiter
-            if delimiter and delimiter in name:
-                index = name.index(delimiter) + len(delimiter)
-                prefix_including_delimiter = name[0:index]
+            # separate keys that contain the same string between the prefix and the first occurrence of the delimiter
+            if delimiter and delimiter in name[len(prefix) :]:
+                end_of_delimiter = (
+                    len(prefix) + name[len(prefix) :].index(delimiter) + len(delimiter)
+                )
+                prefix_including_delimiter = name[0:end_of_delimiter]
                 common_prefixes.append(prefix_including_delimiter)
                 continue
 
@@ -1736,11 +1782,13 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
             lock_until=lock_until,
         )
 
-        keys = [
-            key
-            for key in bucket.keys.getlist(key_name, [])
-            if key.version_id != new_key.version_id
-        ] + [new_key]
+        existing_keys = bucket.keys.getlist(key_name, [])
+        if bucket.is_versioned:
+            keys = existing_keys + [new_key]
+        else:
+            for key in existing_keys:
+                key.dispose()
+            keys = [new_key]
         bucket.keys.setlist(key_name, keys)
 
         notifications.send_event(
@@ -1870,6 +1918,9 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
         bucket.set_cors(cors_rules)
 
     def put_bucket_logging(self, bucket_name, logging_config):
+        """
+        The logging functionality itself is not yet implemented - we only store the configuration for now.
+        """
         bucket = self.get_bucket(bucket_name)
         bucket.set_logging(logging_config, self)
 
@@ -1920,20 +1971,6 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
             pub_block_config.get("RestrictPublicBuckets"),
         )
 
-    def complete_multipart(self, bucket_name, multipart_id, body):
-        bucket = self.get_bucket(bucket_name)
-        multipart = bucket.multiparts[multipart_id]
-        value, etag = multipart.complete(body)
-        if value is None:
-            return
-        del bucket.multiparts[multipart_id]
-
-        key = self.put_object(
-            bucket_name, multipart.key_name, value, etag=etag, multipart=multipart
-        )
-        key.set_metadata(multipart.metadata)
-        return key
-
     def abort_multipart_upload(self, bucket_name, multipart_id):
         bucket = self.get_bucket(bucket_name)
         multipart_data = bucket.multiparts.get(multipart_id, None)
