@@ -30,6 +30,15 @@ class SecretHasNoValueException(SecretsManagerClientError):
         )
 
 
+class SecretStageVersionMismatchException(SecretsManagerClientError):
+    def __init__(self):
+        self.code = 404
+        super().__init__(
+            "InvalidRequestException",
+            message="You provided a VersionStage that is not associated to the provided VersionId.",
+        )
+
+
 class ClientError(SecretsManagerClientError):
     def __init__(self, message):
         super().__init__("InvalidParameterValue", message)
