@@ -5,11 +5,10 @@ import requests
 import re
 
 from collections import OrderedDict
-from moto.core import BaseBackend, BaseModel, CloudFormationModel
+from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
 from moto.core.utils import (
     iso_8601_datetime_with_milliseconds,
     camelcase_to_underscores,
-    BackendDict,
 )
 from moto.moto_api._internal import mock_random
 from moto.sqs import sqs_backends
