@@ -1,13 +1,17 @@
 import json
 
 from moto.core.responses import BaseResponse
+from .exceptions import ValidationException
 from .models import ssm_backends
 
 
 class SimpleSystemManagerResponse(BaseResponse):
+    def __init__(self):
+        super().__init__(service_name="ssm")
+
     @property
     def ssm_backend(self):
-        return ssm_backends[self.region]
+        return ssm_backends[self.current_account][self.region]
 
     @property
     def request_params(self):
@@ -178,6 +182,14 @@ class SimpleSystemManagerResponse(BaseResponse):
         name = self._get_param("Name")
         with_decryption = self._get_param("WithDecryption")
 
+        if (
+            name.startswith("/aws/reference/secretsmanager/")
+            and with_decryption is not True
+        ):
+            raise ValidationException(
+                "WithDecryption flag must be True for retrieving a Secret Manager secret."
+            )
+
         result = self.ssm_backend.get_parameter(name)
 
         if result is None:
