@@ -1,5 +1,4 @@
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel
 from moto.utilities.tagging_service import TaggingService
 from .exceptions import ResourceNotFound
 
@@ -218,5 +217,7 @@ timestreamwrite_backends = BackendDict(
         "us-west-2",
         "eu-central-1",
         "eu-west-1",
+        "ap-southeast-2",
+        "ap-northeast-1",
     ],
 )
