@@ -2,8 +2,8 @@ import json
 import hashlib
 import pkgutil
 
-
 from collections.abc import MutableMapping
+from typing import Any, Dict
 
 
 def str2bool(v):
@@ -13,7 +13,7 @@ def str2bool(v):
         return False
 
 
-def load_resource(package, resource, as_json=True):
+def load_resource(package: str, resource: str, as_json: bool = True) -> Dict[str, Any]:
     """
     Open a file, and return the contents as JSON.
     Usage:
@@ -23,7 +23,7 @@ def load_resource(package, resource, as_json=True):
     return json.loads(resource) if as_json else resource.decode("utf-8")
 
 
-def merge_multiple_dicts(*args):
+def merge_multiple_dicts(*args: Any) -> Dict[str, any]:
     result = {}
     for d in args:
         result.update(d)
@@ -48,7 +48,7 @@ def filter_resources(resources, filters, attr_pairs):
     return result
 
 
-def md5_hash(data=None):
+def md5_hash(data: Any = None) -> Any:
     """
     MD5-hashing for non-security usecases.
     Required for Moto to work in FIPS-enabled systems
